Scanpydoc
=========

.. automodule:: scanpydoc
   :members:

Included extensions
-------------------

.. autosummary::
   :toctree: .

   autosummary_generate_imported
   definition_list_typed_field
   elegant_typehints
   rtd_github_links
   theme
